# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Summary:	Manage IO on many file handles
Name:		perl-IO-Multiplex
Version:	1.16
Release:	25.%{__distinit}%{__distvers}
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/IO-Multiplex
Source0:	https://cpan.metacpan.org/modules/by-module/IO/IO-Multiplex-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(Carp)
BuildRequires:	perl(constant)
BuildRequires:	perl(Fcntl)
BuildRequires:	perl(FileHandle)
BuildRequires:	perl(IO::Handle)
BuildRequires:	perl(POSIX)
BuildRequires:	perl(Socket)
BuildRequires:	perl(strict)
BuildRequires:	perl(Tie::Handle)
BuildRequires:	perl(Time::HiRes)
BuildRequires:	perl(vars)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(IO::Socket)
BuildRequires:	perl(Test)
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(Time::HiRes)

%description
IO::Multiplex is designed to take the effort out of managing multiple file
handles. It is essentially a really fancy front end to the select system call.
In addition to maintaining the select loop, it buffers all input and output
to/from the file handles. It can also accept incoming connections on one or
more listen sockets.

%prep
%setup -q -n IO-Multiplex-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%doc Changes README TODO
%{perl_vendorlib}/IO/
%{_mandir}/man3/IO::Multiplex.3*

%changelog
* Mon Apr 24 2023 Paul Howarth <paul@city-fan.org> - 1.16-25
- Use SPDX-format license tag

* Thu Jun  6 2019 Paul Howarth <paul@city-fan.org> - 1.16-13
- Perl 5.30 rebuild

* Sat Apr 28 2018 Paul Howarth <paul@city-fan.org> - 1.16-9
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Sat Aug 27 2016 Paul Howarth <paul@city-fan.org> - 1.16-5
- BR: perl-generators where available
- Simplify find command using -delete

* Mon Jun 15 2015 Paul Howarth <paul@city-fan.org> - 1.16-2
- Perl 5.22 rebuild

* Fri Apr 10 2015 Paul Howarth <paul@city-fan.org> - 1.16-1
- Update to 1.16
  - Fix descriptor memory leak: Make $mux->close actually untie *$fh

* Wed Apr  1 2015 Paul Howarth <paul@city-fan.org> - 1.15-1
- Update to 1.15
  - Move untie patch to the right place

* Tue Mar 31 2015 Paul Howarth <paul@city-fan.org> - 1.14-1
- Update to 1.14
  - Fix 110_ntest to avoid reading from muxed handle
  - Apply patch to prevent untie warnings (CPAN RT#67846)
- This release by BBB → update source URL
- Classify buildreqs by usage
- Drop %%defattr, redundant since rpm 4.4

* Fri Jun  8 2012 Paul Howarth <paul@city-fan.org> - 1.13-3
- BR: perl core modules that might be dual-lived
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Mon Jun 27 2011 Paul Howarth <paul@city-fan.org> - 1.13-2
- Rebuild for perl 5.14.1 in Rawhide
- Fix dist tag for CentOS 6 and Scientific Linux

* Fri Apr 15 2011 Paul Howarth <paul@city-fan.org> - 1.13-1
- Update to 1.13
  - Fix handling of outbuf that contains '0' (CPAN RT#67458)
- Nobody else likes macros for commands

* Thu Feb 24 2011 Paul Howarth <paul@city-fan.org> - 1.12-1
- Update to 1.12
  - Fixes for Windows (CPAN RT#66096)

* Mon Feb 21 2011 Paul Howarth <paul@city-fan.org> - 1.11-1
- Update to 1.11
  - Avoid warning while adding pipe (CPAN RT#16259, CPAN RT#60068)
  - Add EWOULDBLOCK and non-blocking mode for windows (CPAN RT#23982)
  - Fix typo in documentation (CPAN RT#21085)
  - Avoid shutdown after close (CPAN RT#5885, CPAN RT#5715)
  - Use length of outbuf, not exists to see if it is empty
  - Turn "use warnings" on
- This release by MARKOV -> update source URL

* Fri Jun 25 2010 Paul Howarth <paul@city-fan.org> - 1.10-5
- Rebuild for perl 5.12.1 in Rawhide

* Sat Jun  5 2010 Paul Howarth <paul@city-fan.org> - 1.10-4
- Fix dist tag for RHEL-6 Beta

* Tue Feb 23 2010 Paul Howarth <paul@city-fan.org> - 1.10-3
- Dist tag for Rawhide no longer needs special-casing
- Use %%{_fixperms} macro instead of our own %%{__chmod} incantation

* Fri Sep 11 2009 Paul Howarth <paul@city-fan.org> - 1.10-2
- Define RPM macros in global scope

* Tue Sep 16 2008 Paul Howarth <paul@city-fan.org> - 1.10-1
- Update to 1.10
- License changed to GPL version 1 or later, or Artistic (i.e. same as perl)
- Add buildreq perl(ExtUtils::MakeMaker)

* Mon Mar  5 2007 Paul Howarth <paul@city-fan.org> - 1.09-1
- Update to 1.09
- Fix argument order for find with -depth
- Fix dist tag for Fedora 7 onwards

* Mon Jan  9 2006 Paul Howarth <paul@city-fan.org> - 1.08-1
- Package created as requirement for Net::Server package
